@@ -1,5 +1,5 @@
 package Dist::Zooky;
-$Dist::Zooky::VERSION = '0.14';
+$Dist::Zooky::VERSION = '0.16';
 # ABSTRACT: converts a distribution to Dist::Zilla
 
 use strict;
@@ -17,13 +17,21 @@ has 'make' => (
   isa => 'Str',
 );
 
+has 'metafile' => (
+  is => 'ro',
+  isa => 'Bool',
+);
+
 sub examine {
   my $self = shift;
 
   die "Hey, you already have a 'dist.ini' giving up\n" if -e 'dist.ini';
 
   my $type;
-  if ( -e 'Build.PL' ) {
+  if ( $self->metafile ) {
+    $type = 'FromMETA';
+  }
+  elsif ( -e 'Build.PL' ) {
     $type = 'ModBuild';
   }
   elsif ( -e 'Makefile.PL' ) {
@@ -98,7 +106,7 @@ Dist::Zooky - converts a distribution to Dist::Zilla
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -135,7 +143,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Chris Williams.
+This software is copyright (c) 2015 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
